@@ -28,11 +28,12 @@ import {
   Modal,
   RelativeTimeRangePicker,
   Switch,
+  TextLink,
   useStyles2,
 } from '@grafana/ui';
 import { getModalStyles } from '@grafana/ui/internal';
 import { QueryOperationAction } from 'app/core/components/QueryOperationRow/QueryOperationAction';
-import { contextSrv } from 'app/core/core';
+import { contextSrv } from 'app/core/services/context_srv';
 import { variableAdapters } from 'app/features/variables/adapters';
 import { hasOptions } from 'app/features/variables/guard';
 import { getVariables } from 'app/features/variables/state/selectors';
@@ -284,7 +285,16 @@ export const CreateRecordedQueryUnconnected = ({ query, queries, dataSource, var
           reportInteraction('cloud_user_clicked_create_recorded_query_icon');
         }}
       />
-      <Modal isOpen={isOpen} title={title} onDismiss={closeModal} className={styles.modal}>
+      <Modal
+        ariaLabel={t(
+          'recorded-queries.create-recorded-query-unconnected.title-create-recorded-query',
+          'Create recorded query'
+        )}
+        isOpen={isOpen}
+        title={title}
+        onDismiss={closeModal}
+        className={styles.modal}
+      >
         {recordedQueriesDeprecationNotice()}
         <Form onSubmit={submitForm} validateOn="all">
           {({ register, errors, control, getValues }) => (
@@ -481,7 +491,10 @@ const contactSupportMessage = (token?: LicenseToken) => {
   return (
     <>
       <Trans i18nKey="recorded-queries.create-recorded-query-unconnected.contact-support">
-        To submit a support ticket to Grafana Labs, complete the <a href={href}>Contact Grafana Labs</a>
+        To submit a support ticket to Grafana Labs, complete the{' '}
+        <TextLink external href={href}>
+          Contact Grafana Labs
+        </TextLink>
       </Trans>
     </>
   );
